Package: speechmatics
Title: Client for the 'Speechmatics' Speech-to-Text API
Version: 0.1.0
Authors@R: 
    person("Nic", "Crane", , "thisisnic@gmail.com", role = c("aut", "cre", "cph"))
Description: Transcribe audio files using the 'Speechmatics'
    speech-to-text API <https://www.speechmatics.com/>. Supports custom
    vocabulary, speaker diarization, punctuation control, and audio
    filtering.
URL: https://github.com/thisisnic/speechmatics,
        https://thisisnic.github.io/speechmatics/
BugReports: https://github.com/thisisnic/speechmatics/issues
License: MIT + file LICENSE
Imports: cli, curl, httr2 (>= 1.2.0), jsonlite, rlang
Depends: R (>= 4.2.0)
Encoding: UTF-8
RoxygenNote: 8.0.0
Suggests: knitr, rmarkdown, testthat (>= 3.0.0), vcr (>= 2.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-06-06 18:46:50 UTC; nic
Author: Nic Crane [aut, cre, cph]
Maintainer: Nic Crane <thisisnic@gmail.com>
Repository: CRAN
Date/Publication: 2026-06-12 11:30:02 UTC

# Generated by roxygen2: do not edit by hand

export(sm_delete_job)
export(sm_diarize_channel)
export(sm_diarize_speaker)
export(sm_get_transcript)
export(sm_list_jobs)
export(sm_transcribe)
export(sm_transcription_config)
importFrom(rlang,"%||%")

# speechmatics

An R client for the [Speechmatics](https://www.speechmatics.com/) speech-to-text API.

## Installation

```r
# install.packages("pak")
pak::pak("thisisnic/speechmatics")
```

## Setup

Set your API key as an environment variable:

```r
Sys.setenv(SPEECHMATICS_API_KEY = "your-key-here")
```

Or add it to your `.Renviron`:

```
SPEECHMATICS_API_KEY=your-key-here
```

## Usage

```r
library(speechmatics)

# Transcribe an audio file (writes `./testrecording.txt`)
audio <- system.file("extdata", "testrecording.mp3", package = "speechmatics")
sm_transcribe(audio)
#> ✔ Submitting 'testrecording.mp3'
#> ℹ Job ID: "2om9psu1np"
#> ✔ Waiting for transcription [5.8s]
#> ✔ Saved to testrecording.txt

# Specify output path
sm_transcribe(audio, "output.txt")
#> ✔ Submitting 'testrecording.mp3'
#> ℹ Job ID: "2om9psu1np"
#> ✔ Waiting for transcription [5.8s]
#> ✔ Saved to output.txt

# Enhanced quality with speaker diarization
sm_transcribe(
  audio,
  config = sm_transcription_config(
    quality = "enhanced",
    diarization = sm_diarize_speaker()
  )
)
#> ✔ Submitting 'testrecording.mp3'
#> ℹ Job ID: "3kn7xr2abc"
#> ✔ Waiting for transcription [7.2s]
#> ✔ Saved to testrecording.txt
```

## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  eval = FALSE
)

## -----------------------------------------------------------------------------
# Sys.setenv(SPEECHMATICS_API_KEY = "your-key-here")

## -----------------------------------------------------------------------------
# library(speechmatics)
# 
# audio <- system.file("extdata", "testrecording.mp3", package = "speechmatics")
# sm_transcribe(audio)
# #> ✔ Submitting 'testrecording.mp3'
# #> ℹ Job ID: "2om9psu1np"
# #> ✔ Waiting for transcription [5.8s]
# #> ✔ Saved to testrecording.txt

## -----------------------------------------------------------------------------
# sm_transcribe(audio, "my_transcript.txt")
# #> ✔ Submitting 'testrecording.mp3'
# #> ℹ Job ID: "2om9psu1np"
# #> ✔ Waiting for transcription [5.8s]
# #> ✔ Saved to my_transcript.txt

## -----------------------------------------------------------------------------
# # French, enhanced quality
# sm_transcribe(
#   audio,
#   config = sm_transcription_config(language = "fr", quality = "enhanced")
# )
# #> ✔ Submitting 'testrecording.mp3'
# #> ℹ Job ID: "2om9psu1np"
# #> ✔ Waiting for transcription [6.1s]
# #> ✔ Saved to testrecording.txt

## -----------------------------------------------------------------------------
# sm_transcribe(
#   audio,
#   config = sm_transcription_config(diarization = sm_diarize_speaker())
# )
# #> ✔ Submitting 'testrecording.mp3'
# #> ℹ Job ID: "3kn7xr2abc"
# #> ✔ Waiting for transcription [7.2s]
# #> ✔ Saved to testrecording.txt

## -----------------------------------------------------------------------------
# sm_transcribe(
#   audio,
#   config = sm_transcription_config(
#     diarization = sm_diarize_channel(labels = c("Agent", "Caller"))
#   )
# )
# #> ✔ Submitting 'testrecording.mp3'
# #> ℹ Job ID: "5pq2mt4def"
# #> ✔ Waiting for transcription [6.5s]
# #> ✔ Saved to testrecording.txt

## -----------------------------------------------------------------------------
# # list all jobs
# jobs <- sm_list_jobs()
# jobs
# #>           id status               created_at             data_name duration
# #> 1 2om9psu1np   done 2026-06-06T08:12:19.089Z     testrecording.mp3        3
# #> 2 w06jp9mjvm   done 2026-06-04T10:19:28.351Z               idea-morning-walk.mp3     2037
# #> 3 xco00nzvpq   done 2026-06-01T11:33:28.303Z conf-talk.mp3     1501
# #>   language operating_point diarization
# #> 1       en        standard        <NA>
# #> 2       en        enhanced     speaker
# #> 3       en        enhanced     speaker
# 
# # get a transcript in different formats
# sm_get_transcript("2om9psu1np")
# #> [1] "Hi. This is a test recording."
# 
# sm_get_transcript("2om9psu1np", format = "srt")
# #> [1] "1\n00:00:00,000 --> 00:00:02,000\nHi. This is a test recording.\n"
# 
# sm_get_transcript("2om9psu1np", format = "json-v2")
# #> $format
# #> [1] "2.9"
# #>
# #> $job
# #> $job$created_at
# #> [1] "2026-06-06T08:12:19.089Z"
# #>
# #> $job$data_name
# #> [1] "testrecording.mp3"
# #>
# #> $results
# #> $results[[1]]
# #> $results[[1]]$alternatives
# #> $results[[1]]$alternatives[[1]]
# #> $results[[1]]$alternatives[[1]]$confidence
# #> [1] 1
# #>
# #> $results[[1]]$alternatives[[1]]$content
# #> [1] "Hi"
# #>
# #> ...
# 
# # delete a job
# sm_delete_job("2om9psu1np")

#' Configure speaker diarization
#'
#' @param sensitivity Numeric 0-1 (default `0.5`). Higher values detect more
#'   speakers.
#' @param prefer_current Logical. Reduces false switches between
#'   similar-sounding speakers.
#' @return A diarization config list.
#' @examples
#' sm_diarize_speaker()
#' sm_diarize_speaker(sensitivity = 0.8, prefer_current = TRUE)
#' @export
sm_diarize_speaker <- function(sensitivity = 0.5, prefer_current = FALSE) {
  list(
    diarization = "speaker",
    speaker_diarization_config = list(
      speaker_sensitivity = sensitivity,
      prefer_current_speaker = prefer_current
    )
  )
}

#' Configure channel diarization
#'
#' @param labels Character vector of channel labels (e.g. `c("Agent", "Caller")`).
#' @return A diarization config list.
#' @examples
#' sm_diarize_channel()
#'
#' # label channels
#' sm_diarize_channel(labels = c("Nic", "Jess"))
#' @export
sm_diarize_channel <- function(labels = NULL) {
  cfg <- list(diarization = "channel")
  if (!is.null(labels)) {
    cfg$channel_diarization_labels <- labels
  }
  cfg
}

#' Build transcription config
#'
#' @param language Language code (default `"en"`).
#' @param quality `"standard"` or `"enhanced"`.
#' @param diarization A diarization object from `sm_diarize_speaker()` or
#'   `sm_diarize_channel()`, or `NULL` for no diarization.
#' @return A config list suitable for passing to [sm_transcribe()].
#' @examples
#' sm_transcription_config()
#' sm_transcription_config(language = "fr", quality = "enhanced")
#' sm_transcription_config(diarization = sm_diarize_speaker())
#' @export
sm_transcription_config <- function(language = "en",
                      quality = c("standard", "enhanced"),
                      diarization = NULL) {
  quality <- match.arg(quality)

  tc <- list(language = language, operating_point = quality)

  if (!is.null(diarization)) {
    tc <- c(tc, diarization)
  }

  list(type = "transcription", transcription_config = tc)
}

is_replaying <- function() {
  as.logical(Sys.getenv("VCR_IS_REPLAYING", "FALSE"))
}

api_key <- function(error_call = rlang::caller_env()) {
  key <- Sys.getenv("SPEECHMATICS_API_KEY")
  if (nzchar(key)) {
    return(key)
  }
  if (is_replaying()) {
    return("")
  }
  cli::cli_abort("Can't find env var {.envvar SPEECHMATICS_API_KEY}.", call = error_call)
}

#' Build an authenticated API request
#'
#' Creates an httr2 request to the Speechmatics API with bearer token
#' authentication and automatic retries.
#'
#' @return An httr2 request object.
#' @noRd
req <- function() {
  httr2::request("https://asr.api.speechmatics.com/v2") |>
    httr2::req_auth_bearer_token(api_key()) |>
    httr2::req_retry(max_tries = 3, retry_on_failure = TRUE)
}

## Custom aspell dictionaries used by R CMD check's spell check.
## "diarization" is a correctly-spelled speech-to-text term; see
## .aspell/speechmatics.rds.
Rd_files <- vignettes <- R_files <- description <-
  list(encoding = "UTF-8", dictionaries = "speechmatics")

#' Submit a transcription job
#'
#' @param audio_path Path to the audio file.
#' @param config Config list from `transcription_config()`.
#' @return The job ID (character string).
#' @noRd
submit <- function(audio_path, config = sm_transcription_config()) {
  resp <- req() |>
    httr2::req_url_path_append("jobs") |>
    httr2::req_body_multipart(
      data_file = curl::form_file(audio_path),
      config = curl::form_data(jsonlite::toJSON(unclass(config), auto_unbox = TRUE))
    ) |>
    httr2::req_perform()

  httr2::resp_body_json(resp)$id
}

#' List all jobs
#'
#' @return A data frame of jobs.
#' @examples
#' \dontrun{
#' sm_list_jobs()
#' }
#' @export
sm_list_jobs <- function() {
  resp <- req() |>
    httr2::req_url_path_append("jobs") |>
    httr2::req_perform()

  jobs <- httr2::resp_body_json(resp)$jobs
  do.call(rbind, lapply(jobs, function(j) {
    tc <- j$config$transcription_config
    data.frame(
      id = j$id,
      status = j$status,
      created_at = j$created_at,
      data_name = j$data_name,
      duration = j$duration,
      language = tc$language %||% NA_character_,
      operating_point = tc$operating_point %||% NA_character_,
      diarization = tc$diarization %||% NA_character_
    )
  }))
}

#' Get job status
#'
#' @param job_id Job ID string.
#' @return Status string.
#' @noRd
get_status <- function(job_id) {
  resp <- req() |>
    httr2::req_url_path_append("jobs", job_id) |>
    httr2::req_perform()

  httr2::resp_body_json(resp)$job$status
}

#' Get transcript for a completed job
#'
#' @param job_id Job ID string.
#' @param format Output format: `"txt"` for plain text (default), `"srt"` for
#'   subtitles, or `"json-v2"` for structured data with timestamps, speaker
#'   labels, and confidence scores.
#' @return Transcript as a character string (`"txt"` and `"srt"`) or a list
#'   (`"json-v2"`).
#' @examples
#' \dontrun{
#' sm_get_transcript("2om9psu1np")
#' sm_get_transcript("2om9psu1np", format = "srt")
#' sm_get_transcript("2om9psu1np", format = "json-v2")
#' }
#' @export
sm_get_transcript <- function(job_id, format = c("txt", "srt", "json-v2")) {
  format <- match.arg(format)

  resp <- req() |>
    httr2::req_url_path_append("jobs", job_id, "transcript") |>
    httr2::req_url_query(format = format) |>
    httr2::req_perform()

  if (format == "json-v2") {
    httr2::resp_body_json(resp)
  } else {
    httr2::resp_body_string(resp)
  }
}

#' Delete a job
#'
#' @param job_id Job ID string.
#' @return `TRUE`, invisibly.
#' @examples
#' \dontrun{
#' sm_delete_job("2om9psu1np")
#' }
#' @export
sm_delete_job <- function(job_id) {
  req() |>
    httr2::req_url_path_append("jobs", job_id) |>
    httr2::req_method("DELETE") |>
    httr2::req_perform()

  invisible(TRUE)
}

#' Get usage statistics
#'
#' @return A data frame of usage details by language and operating point.
#' @noRd
usage <- function() {
  resp <- req() |>
    httr2::req_url_path_append("usage") |>
    httr2::req_perform()

  body <- httr2::resp_body_json(resp)
  df <- do.call(rbind, lapply(body$details, as.data.frame))
  df$duration_hrs <- round(df$duration_hrs, 2)
  df
}

#' Transcribe an audio file
#'
#' Submits an audio file to the Speechmatics API, polls until complete,
#' and writes the transcript to a file.
#'
#' @param input Path to the input audio file.
#' @param output Path to the output transcript file. If `NULL` (the default),
#'   the output is written to the working directory with the same name as the
#'   input file but with a `.txt` extension.
#' @param config Config from `sm_transcription_config()`.
#' @param poll_interval Seconds between status checks.
#' @return The output path, invisibly.
#' @examples
#' \dontrun{
#' audio <- system.file("extdata", "testrecording.mp3", package = "speechmatics")
#' sm_transcribe(audio)
#' sm_transcribe(audio, "output.txt")
#' sm_transcribe(audio, config = sm_transcription_config(quality = "enhanced"))
#' }
#' @export
sm_transcribe <- function(input, output = NULL, config = sm_transcription_config(),
                       poll_interval = 5) {
  if (!is.character(input) || length(input) != 1) {
    cli::cli_abort("{.arg input} must be a single string, not {.obj_type_friendly {input}}.")
  }
  if (!file.exists(input)) {
    cli::cli_abort("Can't find file {.path {input}}.")
  }
  if (!is.null(output) && (!is.character(output) || length(output) != 1)) {
    cli::cli_abort("{.arg output} must be a single string or {.code NULL}, not {.obj_type_friendly {output}}.")
  }

  if (is.null(output)) {
    output <- sub("\\.[^.]+$", ".txt", basename(input))
  }

  cli::cli_progress_step("Submitting {.path {input}}")
  job_id <- submit(input, config)
  cli::cli_alert_info("Job ID: {.val {job_id}}")

  cli::cli_progress_step("Waiting for transcription")
  status <- get_status(job_id)
  while (status == "running") {
    Sys.sleep(poll_interval)
    status <- get_status(job_id)
  }

  if (status != "done") {
    cli::cli_abort("Transcription job failed with status {.val {status}}.")
  }

  transcript <- sm_get_transcript(job_id)
  writeLines(transcript, output)
  cli::cli_alert_success("Saved to {.path {output}}")
  invisible(output)
}

test_that("transcribe validates inputs", {
  expect_error(sm_transcribe(123), "must be a single string")
  expect_error(sm_transcribe(c("a.mp3", "b.mp3")), "must be a single string")
  expect_error(sm_transcribe("nonexistent.mp3"), "Can't find file")
  audio <- system.file("extdata", "testrecording.mp3", package = "speechmatics")
  expect_error(sm_transcribe(audio, output = 123), "must be a single string")
})

test_that("get_status returns status string", {
  skip_on_cran()
  vcr::local_cassette("get-status")
  status <- get_status("75m0l7rsfy")
  expect_identical(status, "done")
})

test_that("get_transcript returns transcript text", {
  skip_on_cran()
  vcr::local_cassette("get-transcript")
  transcript <- sm_get_transcript("75m0l7rsfy")
  expect_identical(transcript, "Hi. This is a test recording.")
})

test_that("list_jobs returns a data frame", {
  skip_on_cran()
  vcr::local_cassette("list-jobs")
  jobs <- sm_list_jobs()
  expect_s3_class(jobs, "data.frame")
})

---
title: "Getting Started with speechmatics"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Getting Started with speechmatics}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  eval = FALSE
)
```

## Authentication

The package uses the Speechmatics API, which requires an API key. Sign up at
<https://www.speechmatics.com/> to get one, then set it as an environment
variable:

```{r}
Sys.setenv(SPEECHMATICS_API_KEY = "your-key-here")
```

For persistent use, add it to your `.Renviron` file:

```
SPEECHMATICS_API_KEY=your-key-here
```

## Basic transcription

`sm_transcribe()` submits an audio file, waits for the result, and writes the
transcript to a text file in your working directory:

```{r}
library(speechmatics)

audio <- system.file("extdata", "testrecording.mp3", package = "speechmatics")
sm_transcribe(audio)
#> ✔ Submitting 'testrecording.mp3'
#> ℹ Job ID: "2om9psu1np"
#> ✔ Waiting for transcription [5.8s]
#> ✔ Saved to testrecording.txt
```

You can also specify the output path:

```{r}
sm_transcribe(audio, "my_transcript.txt")
#> ✔ Submitting 'testrecording.mp3'
#> ℹ Job ID: "2om9psu1np"
#> ✔ Waiting for transcription [5.8s]
#> ✔ Saved to my_transcript.txt
```

## Configuration

Use `sm_transcription_config()` to control language, quality, and diarization:

```{r}
# French, enhanced quality
sm_transcribe(
  audio,
  config = sm_transcription_config(language = "fr", quality = "enhanced")
)
#> ✔ Submitting 'testrecording.mp3'
#> ℹ Job ID: "2om9psu1np"
#> ✔ Waiting for transcription [6.1s]
#> ✔ Saved to testrecording.txt
```

### Speaker diarization

Speaker diarization identifies who said what from a single audio channel:

```{r}
sm_transcribe(
  audio,
  config = sm_transcription_config(diarization = sm_diarize_speaker())
)
#> ✔ Submitting 'testrecording.mp3'
#> ℹ Job ID: "3kn7xr2abc"
#> ✔ Waiting for transcription [7.2s]
#> ✔ Saved to testrecording.txt
```

### Channel diarization

Channel diarization separates speakers that are already on different audio
channels:

```{r}
sm_transcribe(
  audio,
  config = sm_transcription_config(
    diarization = sm_diarize_channel(labels = c("Agent", "Caller"))
  )
)
#> ✔ Submitting 'testrecording.mp3'
#> ℹ Job ID: "5pq2mt4def"
#> ✔ Waiting for transcription [6.5s]
#> ✔ Saved to testrecording.txt
```

## Managing jobs

You can work with jobs directly using the lower-level functions:

```{r}
# list all jobs
jobs <- sm_list_jobs()
jobs
#>           id status               created_at             data_name duration
#> 1 2om9psu1np   done 2026-06-06T08:12:19.089Z     testrecording.mp3        3
#> 2 w06jp9mjvm   done 2026-06-04T10:19:28.351Z               idea-morning-walk.mp3     2037
#> 3 xco00nzvpq   done 2026-06-01T11:33:28.303Z conf-talk.mp3     1501
#>   language operating_point diarization
#> 1       en        standard        <NA>
#> 2       en        enhanced     speaker
#> 3       en        enhanced     speaker

# get a transcript in different formats
sm_get_transcript("2om9psu1np")
#> [1] "Hi. This is a test recording."

sm_get_transcript("2om9psu1np", format = "srt")
#> [1] "1\n00:00:00,000 --> 00:00:02,000\nHi. This is a test recording.\n"

sm_get_transcript("2om9psu1np", format = "json-v2")
#> $format
#> [1] "2.9"
#>
#> $job
#> $job$created_at
#> [1] "2026-06-06T08:12:19.089Z"
#>
#> $job$data_name
#> [1] "testrecording.mp3"
#>
#> $results
#> $results[[1]]
#> $results[[1]]$alternatives
#> $results[[1]]$alternatives[[1]]
#> $results[[1]]$alternatives[[1]]$confidence
#> [1] 1
#>
#> $results[[1]]$alternatives[[1]]$content
#> [1] "Hi"
#>
#> ...

# delete a job
sm_delete_job("2om9psu1np")
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/config.R
\name{sm_transcription_config}
\alias{sm_transcription_config}
\title{Build transcription config}
\usage{
sm_transcription_config(
  language = "en",
  quality = c("standard", "enhanced"),
  diarization = NULL
)
}
\arguments{
\item{language}{Language code (default \code{"en"}).}

\item{quality}{\code{"standard"} or \code{"enhanced"}.}

\item{diarization}{A diarization object from \code{sm_diarize_speaker()} or
\code{sm_diarize_channel()}, or \code{NULL} for no diarization.}
}
\value{
A config list suitable for passing to \code{\link[=sm_transcribe]{sm_transcribe()}}.
}
\description{
Build transcription config
}
\examples{
sm_transcription_config()
sm_transcription_config(language = "fr", quality = "enhanced")
sm_transcription_config(diarization = sm_diarize_speaker())
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transcribe.R
\name{sm_delete_job}
\alias{sm_delete_job}
\title{Delete a job}
\usage{
sm_delete_job(job_id)
}
\arguments{
\item{job_id}{Job ID string.}
}
\value{
\code{TRUE}, invisibly.
}
\description{
Delete a job
}
\examples{
\dontrun{
sm_delete_job("2om9psu1np")
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transcribe.R
\name{sm_transcribe}
\alias{sm_transcribe}
\title{Transcribe an audio file}
\usage{
sm_transcribe(
  input,
  output = NULL,
  config = sm_transcription_config(),
  poll_interval = 5
)
}
\arguments{
\item{input}{Path to the input audio file.}

\item{output}{Path to the output transcript file. If \code{NULL} (the default),
the output is written to the working directory with the same name as the
input file but with a \code{.txt} extension.}

\item{config}{Config from \code{sm_transcription_config()}.}

\item{poll_interval}{Seconds between status checks.}
}
\value{
The output path, invisibly.
}
\description{
Submits an audio file to the Speechmatics API, polls until complete,
and writes the transcript to a file.
}
\examples{
\dontrun{
audio <- system.file("extdata", "testrecording.mp3", package = "speechmatics")
sm_transcribe(audio)
sm_transcribe(audio, "output.txt")
sm_transcribe(audio, config = sm_transcription_config(quality = "enhanced"))
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transcribe.R
\name{sm_list_jobs}
\alias{sm_list_jobs}
\title{List all jobs}
\usage{
sm_list_jobs()
}
\value{
A data frame of jobs.
}
\description{
List all jobs
}
\examples{
\dontrun{
sm_list_jobs()
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/config.R
\name{sm_diarize_channel}
\alias{sm_diarize_channel}
\title{Configure channel diarization}
\usage{
sm_diarize_channel(labels = NULL)
}
\arguments{
\item{labels}{Character vector of channel labels (e.g. \code{c("Agent", "Caller")}).}
}
\value{
A diarization config list.
}
\description{
Configure channel diarization
}
\examples{
sm_diarize_channel()

# label channels
sm_diarize_channel(labels = c("Nic", "Jess"))
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/speechmatics-package.R
\docType{package}
\name{speechmatics-package}
\alias{speechmatics}
\alias{speechmatics-package}
\title{speechmatics: Client for the 'Speechmatics' Speech-to-Text API}
\description{
Transcribe audio files using the 'Speechmatics' speech-to-text API \url{https://www.speechmatics.com/}. Supports custom vocabulary, speaker diarization, punctuation control, and audio filtering.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/thisisnic/speechmatics}
  \item \url{https://thisisnic.github.io/speechmatics/}
  \item Report bugs at \url{https://github.com/thisisnic/speechmatics/issues}
}

}
\author{
\strong{Maintainer}: Nic Crane \email{thisisnic@gmail.com} [copyright holder]

Authors:
\itemize{
  \item Nic Crane \email{thisisnic@gmail.com} [copyright holder]
}

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transcribe.R
\name{sm_get_transcript}
\alias{sm_get_transcript}
\title{Get transcript for a completed job}
\usage{
sm_get_transcript(job_id, format = c("txt", "srt", "json-v2"))
}
\arguments{
\item{job_id}{Job ID string.}

\item{format}{Output format: \code{"txt"} for plain text (default), \code{"srt"} for
subtitles, or \code{"json-v2"} for structured data with timestamps, speaker
labels, and confidence scores.}
}
\value{
Transcript as a character string (\code{"txt"} and \code{"srt"}) or a list
(\code{"json-v2"}).
}
\description{
Get transcript for a completed job
}
\examples{
\dontrun{
sm_get_transcript("2om9psu1np")
sm_get_transcript("2om9psu1np", format = "srt")
sm_get_transcript("2om9psu1np", format = "json-v2")
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/config.R
\name{sm_diarize_speaker}
\alias{sm_diarize_speaker}
\title{Configure speaker diarization}
\usage{
sm_diarize_speaker(sensitivity = 0.5, prefer_current = FALSE)
}
\arguments{
\item{sensitivity}{Numeric 0-1 (default \code{0.5}). Higher values detect more
speakers.}

\item{prefer_current}{Logical. Reduces false switches between
similar-sounding speakers.}
}
\value{
A diarization config list.
}
\description{
Configure speaker diarization
}
\examples{
sm_diarize_speaker()
sm_diarize_speaker(sensitivity = 0.8, prefer_current = TRUE)
}
